@@ -20,7 +20,7 @@
 #include <QPushButton>
 #include <QSettings>
 #include <QFile>
-#include "widgets/contactwidget.h"
+#include <QCheckBox>
 #include "commonstatic.h"
 
 ContactsWindow::ContactsWindow(QWidget *parent, Group* group) :
@@ -42,18 +42,8 @@ ContactsWindow::ContactsWindow(QWidget *parent, Group* group) :
 #ifdef Q_WS_MAEMO_5
     setAttribute(Qt::WA_Maemo5NonComposited, true);
     setAttribute(Qt::WA_Maemo5AutoOrientation, true);
-    ui->scrollArea->setVerticalScrollBarPolicy(Qt::ScrollBarAsNeeded);
-    ui->scrollArea->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
 #endif
 
-    if (ui->scrollAreaWidgetContents->layout() == NULL){
-        QVBoxLayout* layout = new QVBoxLayout(ui->scrollAreaWidgetContents);
-        ui->scrollAreaWidgetContents->setLayout(layout);
-        layout->setAlignment(Qt::AlignTop);
-        layout->setSpacing(0);
-        layout->setContentsMargins(3,3,3,3);
-    }
-
     ui->txtCerca->grabKeyboard();
     connect(ui->txtCerca, SIGNAL(textChanged(QString)), this, SLOT(CercaSlot()));
     connect(ui->btnClear, SIGNAL(clicked()), this, SLOT(ClearSlot()));
@@ -69,6 +59,11 @@ void ContactsWindow::FillContactsList()
 {
     m_Contacts = CommonStatic::ContactsCache;
 
+    connect(ui->tblContacts, SIGNAL(cellDoubleClicked(int,int)), this, SLOT(ContactDoubleClicked(int, int)));
+    ui->tblContacts->setSortingEnabled(false);
+    ui->tblContacts->setColumnCount(4);
+    ui->tblContacts->setRowCount(m_Contacts.count());
+
 #ifdef Q_WS_MAEMO_5
     setAttribute(Qt::WA_Maemo5ShowProgressIndicator, true);
 #endif
@@ -78,25 +73,53 @@ void ContactsWindow::FillContactsList()
     int count = 0;
     foreach (Contact* c, m_Contacts){
         if (!m_Group->Contains(c->Number)){
-            AddContactToList(c, i, cImage);
+            AddContactToList(c, count, i, cImage);
             count++;
         }
         i++;
     }
     delete cImage;
 
+    ui->tblContacts->setRowCount(count);
+    ui->tblContacts->sortItems(2, Qt::AscendingOrder);
+    ui->tblContacts->resizeColumnToContents(0);
+    ui->tblContacts->resizeColumnToContents(1);
+
     setWindowTitle(tr("Address book (%1)").arg(count));
+    resizeEvent(NULL);
 #ifdef Q_WS_MAEMO_5
     setAttribute(Qt::WA_Maemo5ShowProgressIndicator, false);
 #endif
 }
 
-void ContactsWindow::AddContactToList(Contact* c, int index, QPixmap* defaultImage)
+void ContactsWindow::AddContactToList(Contact* c, int row, int index, QPixmap* defaultImage)
 {    
-    ContactWidget* w = new ContactWidget(this, c, defaultImage);
-    connect(w, SIGNAL(doubleClicked()), this, SLOT(ContactDoubleClicked()));
-    w->setObjectName(QString("%1").arg(index));
-    ui->scrollAreaWidgetContents->layout()->addWidget(w);
+    ui->tblContacts->setRowHeight(row, 60);
+    QCheckBox* chk = new QCheckBox(ui->tblContacts);
+    chk->setObjectName(QString("%1").arg(index));
+    chk->setStyleSheet("border-style: none;");
+    chk->setText("");
+    ui->tblContacts->setCellWidget(row, 0, chk);
+
+    QLabel* lbl = new QLabel(this);
+    lbl->setAlignment(Qt::AlignCenter);
+    lbl->setMaximumWidth(48);
+    if (c->Thumbnail != NULL)
+        lbl->setPixmap(QPixmap::fromImage(*c->Thumbnail).scaled(48, 48, Qt::KeepAspectRatio));
+    else{
+        QPixmap* cImage = defaultImage;
+        lbl->setPixmap(cImage->scaled(48, 48, Qt::KeepAspectRatio));
+    }
+    ui->tblContacts->setCellWidget(row, 1, lbl);
+
+    lbl = new QLabel(0);
+    lbl->setText(c->Name);
+    ui->tblContacts->setCellWidget(row, 2, lbl);
+
+    QTableWidgetItem* item = new QTableWidgetItem(0);
+    item->setText(c->Number);
+    item->setTextAlignment(Qt::AlignHCenter | Qt::AlignRight);
+    ui->tblContacts->setItem(row, 3, item);
 }
 
 QList<Contact*> ContactsWindow::GetSelectedContacts()
@@ -110,7 +133,7 @@ void ContactsWindow::Init()
     setAttribute(Qt::WA_Maemo5ShowProgressIndicator, true);
 #endif
     m_Timer = new QTimer();
-    m_Timer->setInterval(300);
+    m_Timer->setInterval(100);
     m_Timer->setSingleShot(true);
     connect(m_Timer, SIGNAL(timeout()), this, SLOT(TimerSlot()));
     m_Timer->start();
@@ -133,23 +156,24 @@ void ContactsWindow::CercaSlot()
 #endif
     ui->txtCerca->setFocus();
 
-    QWidget* child;
     int count = 0;
-    for (int i=0; i<ui->scrollAreaWidgetContents->layout()->count(); i++){
-        child = ui->scrollAreaWidgetContents->layout()->itemAt(i)->widget();
-        if (child){
-            int index = child->objectName().toInt();
-            Contact* c = m_Contacts.at(index);
-            if (ui->txtCerca->text().isEmpty() || c->Name.contains(ui->txtCerca->text(), Qt::CaseInsensitive)){
-                ContactWidget* cw = (ContactWidget*)child;
-                if (ui->txtCerca->text().isEmpty())
-                    cw->SelectText(c->Name);
-                else
-                    cw->SelectText(ui->txtCerca->text());
-                cw->setVisible(true);
-                count++;
-            }else
-                child->setVisible(false);
+    for (int i=0; i<ui->tblContacts->rowCount(); i++){
+        QCheckBox* chk = (QCheckBox*)ui->tblContacts->cellWidget(i, 0);
+        int index = chk->objectName().toInt();
+        Contact* c = m_Contacts.at(index);
+        if (c){
+            QLabel* lbl = (QLabel*)ui->tblContacts->cellWidget(i, 2);
+            if (lbl){
+                QString text = c->Name;
+                if (ui->txtCerca->text().isEmpty() || text.contains(ui->txtCerca->text(), Qt::CaseInsensitive)){
+                    if (!ui->txtCerca->text().isEmpty())
+                        text.replace(ui->txtCerca->text(), QString("<b>%1</b>").arg(ui->txtCerca->text()), Qt::CaseInsensitive);
+                    lbl->setText(text);
+                    ui->tblContacts->setRowHidden(i, false);
+                    count++;
+                }else
+                    ui->tblContacts->setRowHidden(i, true);
+            }
         }
     }
 
@@ -168,25 +192,29 @@ void ContactsWindow::OkSlot()
 {
     m_Selected.clear();
 
-    QWidget* child;
-    for (int i=0; i<ui->scrollAreaWidgetContents->layout()->count(); i++){
-        child = ui->scrollAreaWidgetContents->layout()->itemAt(i)->widget();
-        if (child){
-            if (((ContactWidget*)child)->IsSelected()){
-                int index = child->objectName().toInt();
-                Contact* c = m_Contacts.at(index);                
-                m_Selected.append(c);
-            }
+    for (int i=0; i<ui->tblContacts->rowCount(); i++){
+        QCheckBox* chk = (QCheckBox*)ui->tblContacts->cellWidget(i, 0);
+        if (chk && chk->isChecked()){
+            int index = chk->objectName().toInt();
+            Contact* c = m_Contacts.at(index);
+            m_Selected.append(c);
         }
     }
 
     accept();
 }
 
-void ContactsWindow::ContactDoubleClicked()
+void ContactsWindow::ContactDoubleClicked(int row, int)
 {
-    ContactWidget* w = (ContactWidget*)sender();
-    if (w != NULL){
-        w->ToggleSelected();
-    }
+    QCheckBox* chk = (QCheckBox*)ui->tblContacts->cellWidget(row, 0);
+    if (chk)
+        chk->setChecked(!chk->isChecked());
+}
+
+void ContactsWindow::resizeEvent (QResizeEvent*)
+{
+    int w = ui->tblContacts->width();
+    w = w - ui->tblContacts->columnWidth(0) - ui->tblContacts->columnWidth(1) - 8;
+    ui->tblContacts->setColumnWidth(2, w / 2);
+    ui->tblContacts->setColumnWidth(3, w / 2);
 }
