@@ -162,3 +162,23 @@ void Group::Remove(QString number)
         delete gc;
     }
 }
+
+bool Group::Delete()
+{
+    if (!IsValid())
+        return false;
+
+    QString query = QString("Delete from groups where g_id=%1").arg(Id);
+    QSqlQuery qry;
+    if (!qry.prepare(query))
+        return false;
+    if (!qry.exec())
+        return false;
+
+    query = QString("Delete from group_contacts where gc_group_id=%1").arg(Id);
+    if (!qry.prepare(query))
+        return false;
+    if (!qry.exec())
+        return false;
+    return true;
+}
