@@ -19,6 +19,7 @@
 #define GROUPACTIONSWINDOW_H
 
 #include <QDialog>
+#include <QMenu>
 #include "group.h"
 #ifdef Q_WS_MAEMO_5
     #include "qtcontacts.h"
@@ -41,10 +42,11 @@ private:
     Ui::GroupActionsWindow *ui;
 
     Group* m_Group;
+    QMenu* m_ContactMenu;
 
     void PopulateContactsTable();
     QList<QString> GetSelectedNumbers();
-    void SelectAllContacts();
+    void SelectAllContacts(bool select=true);
 
 public slots:
     int exec();
@@ -55,6 +57,11 @@ private slots:
     void SendSlot();
     void EditSlot();
     void ContactDoubleClick(int row, int column);
+    void ContactMenuSlot(QPoint point);
+
+    void SelectAllSlot();
+    void DeselectAllSlot();
+    void RemoveOneSlot();
 
 protected:
     void resizeEvent (QResizeEvent*);
