@@ -193,13 +193,21 @@ void MainWindow::AboutSlot()
 
 void MainWindow::show()
 {
+#ifdef Q_WS_MAEMO_5
+    setAttribute(Qt::WA_Maemo5ShowProgressIndicator, true);
+#endif
+    ui->tblGroups->setEnabled(false);
     QMainWindow::show();
-    QTimer::singleShot(300, this, SLOT(TimerSlot()));
+    QTimer::singleShot(100, this, SLOT(TimerSlot()));
 }
 
 void MainWindow::TimerSlot()
 {
     CommonStatic::LoadContactsCache();
+    ui->tblGroups->setEnabled(true);
+#ifdef Q_WS_MAEMO_5
+    setAttribute(Qt::WA_Maemo5ShowProgressIndicator, false);
+#endif
 }
 
 void MainWindow::GroupMenuSlot(QPoint point)
